#
# spec file for package bamf
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libbamf3-2
%define _binver 3
%define _version 0.5
Name:           bamf
Version:        0.5.6
Release:        bp156.2.7
Summary:        Window matching library
License:        GPL-3.0-only AND LGPL-3.0-only
URL:            https://launchpad.net/bamf
Source:         https://launchpad.net/bamf/%{_version}/%{version}/+download/bamf-%{version}.tar.gz
Source2:        https://launchpad.net/bamf/%{_version}/%{version}/+download/bamf-%{version}.tar.gz.asc
Source3:        %{name}.keyring
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  python3-lxml
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.30.0
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.2
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.4.7
BuildRequires:  pkgconfig(x11)

%description
bamf matches application windows to desktop files.

%package daemon
Summary:        Window matching daemon
Requires:       %{lname} = %{version}

%description daemon
bamf matches application windows to desktop files.

This package contains the daemon used by the library and a gio
module that facilitates the matching of applications started
through GDesktopAppInfo

%package doc
Summary:        Documentation for libbamf and libbamf3
BuildArch:      noarch

%description doc
This package contains the documentation for the bamf library.

%package -n %{lname}
Summary:        Window matching library

%description -n %{lname}
bamf matches application windows to desktop files.

This package contains libraries to be used by applications.

%package -n typelib-1_0-Bamf-%{_binver}_0
Summary:        Introspection bindings for the BAMF window matching library

%description -n typelib-1_0-Bamf-%{_binver}_0
This package contains introspection data for the Bamf library.

This package provides the GObject Introspection bindings for Bamf.

%package devel
Summary:        Development files for the BAMF window matching library
Requires:       %{lname} = %{version}
Requires:       typelib-1_0-Bamf-%{_binver}_0

%description devel
bamf matches application windows to desktop files.

This package contains files that are needed to build applications.

%prep
%autosetup

sed -i '/^CFLAGS=/s/-Werror //' configure.ac

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure \
  --disable-static \
  --enable-gtk-doc
%make_build

%install
%make_install

rm -r %{buildroot}%{_datadir}/upstart/

find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files daemon
%license COPYING COPYING.LGPL
%doc ChangeLog TODO
%{_libexecdir}/bamf/
%{_datadir}/dbus-1/services/org.ayatana.bamf.service
%{_userunitdir}/bamfdaemon.service

%files -n %{lname}
%license COPYING COPYING.LGPL
%doc ChangeLog TODO
%{_libdir}/libbamf%{_binver}.so.*

%files -n typelib-1_0-Bamf-%{_binver}_0
%{_libdir}/girepository-1.0/

%files devel
%{_includedir}/libbamf%{_binver}/
%{_libdir}/libbamf%{_binver}.so
%{_datadir}/vala/
%{_datadir}/gir-1.0/
%{_libdir}/pkgconfig/libbamf%{_binver}.pc

%files doc
%doc %{_datadir}/gtk-doc/

%changelog
* Thu Jul 28 2022 Dirk Müller <dmueller@suse.com>
- update to 0.5.6:
  * configure.ac: bump glib requirement to >= 2.38
  * port gobject privates methods using non-deprecated macros
  * bamf-view: Fix deprecation warning with proper replacement
  * libbamf: Use more modern macros to define classes
  * configure: Ensure we compile using all the required gobject packages
  * daemon/bamf-application: Support ShowIn in generated desktop with new format
  * tests/bamfdaemon: Remove window-added/removed tests
  * bamfdaemon, tests: Export and destroy windows and applications
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update keyring for new key Marco Trevisan
  D4C501DA48EB797A081750939449C2F50996635F
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.5.5:
  * bamf-tab: Fix spelling
  * bamf-view: avoid overriding the `timeout` variables after
    setting them
  * Run gtester2xunit.py with Python3, port libxml2/libxslt to
    lxml module, this obsoletes bamf-fix-gtester2xunit.patch
* Mon Dec  9 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.5.4:
  * See /usr/share/doc/packages/bamf-daemon/ChangeLog
- Add bamf-fix-gtester2xunit.patch: Make gtester2xunit requirements
  easier to meet.
  BuildRequire python3-lxml instead of libxslt-python and
  python2-libxml2.
- Drop openSUSE Leap 42.3 support.
* Fri Sep 27 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire python2-libxml2 instead of python-libxml2
* Tue Nov 15 2016 sor.alexei@meowr.ru
- Update to version 0.5.3 (changes since 0.5.1):
  * BamfView: Reload the view children everytime it changes dbus
    path. Without doing it we could have children-less views in
    case we have just re-matched a view with a different dbus path
    (this happens in general for desktop-less applications), because
    the proxy won't be fast enough to catch the signal to update
    the inner children list (lp#1238064).
  * BamfXutils: Trap the X errors when doing async X calls
    (lp#1193714).
  * bamf-legacy-window-test.c: Don't use 'return' with a value, in
    function returning void.
  * Fix return value of try_create_local_desktop_data (lp#1280110).
  * BamfLegacyScreen: When in Unity monitor for compiz
    ClientMessage's to show action menu If we get a
    _COMPIZ_TOOLKIT_ACTION client message with the internal value
    _COMPIZ_TOOLKIT_ACTION_WINDOW_MENU, then we are requested by
    compiz to show the window action menu, and thus let's ask the
    proper BamfLegacyWindow to do that, thanks to libwnck
    (lp#1280042).
  * Remove old webapp related code since now we don't use browser
    tab matching anymore (lp#1289498).
  * Rip out vestigial webapps code (lp#1280337, lp#1280337).
  * BamfMatcher: Fix prefix regex for pythonX support (used for
    converting /usr/bin/python[stuff] foo into foo) to work with
    pythonX as well as python and pythonX.Y.
  * BamfLegacyScreen: Do not show the actions menu for desktop type
    window (lp#1342609).
  * Replace gtk_icon_theme_has_icon with gtk_icon_theme_lookup_icon
    (lp#1407192).
  * Matcher: Honour the _GTK_APPLICATION_ID xprop.
  * BamfMatcher: Rename set our atom to _BAMF_DESKTOP_FILE.
  * Matcher: Use desktop file path when matching on
    _GTK_APPLICATION_ID.
  * BamfMatcher: Update special g-c-c code to unity-control-center
    (lp#1511481).
  * libBAMF: Cache active{window,application} and be smarter in
    reusing known resources.
  * BamfDaemon: Add upstart session support.
  * BamfMatcher: Don't assign no-display desktop files to windows
    by default when launched (lp#1519376).
  * Use startup notifications to set a "starting" property
    (lp#676457).
  * BamfMatcher: Avoid to register applications with invalid (empty
    or not existing) destkop files (lp#1560490).
  * BamfApplication: Bind window-{added,removed} signals to
    child-{added,removed} ones.
  * BamfWindow: Export window actions menu using dbusmenu
    (lp#1570812).
  * BamfApplication: Correctly set a main child when handling
    windows.
  * bamfdaemon-dbus-runner: Don't try to start again if already
    running (lp#1581896, lp#1532226).
  * BamfMatcher: Allow overriding desktop with the environment var
    BAMF_DESKTOP_FILE_HINT.
  * Daemon: Manually set to complete the startup notification on
    view state change (lp#1582430).
  * Add support for starting bamf through user systemd units.
  * Unscale x/y coordinates returned by top_window_action_menu
    (lp#1606234).
  * Adjust for XDG_CURRENT_DESKTOP containing multiple
    colon-separated values.
- Chop -Werror off with a regular expression.
* Sun May 10 2015 jengelh@inai.de
- Add gpg signature
* Sat May  9 2015 jengelh@inai.de
- Update RPM package groups and summaries
- Avoid running configure twice
- Make sure all non-base directories are owned
- Ensure all configure.ac requirements appear as BuildRequires
- Place documentation into subpackage, it is not needed for
  automated builds.
* Sat May  2 2015 sor.alexei@meowr.ru
- Update to 0.5.1:
  * BamfView: Reload the view children everytime it changes D-Bus
    path.
  * BamfXutils: Trap the X errors when doing async X calls.
  * BamfLegacyScreen: When in Unity monitor for Compiz
    ClientMessage's to show action menu.
  * BamfMatcher: Fix prefix regex for pythonX support.
  * BamfMatcher: Rename set our atom to _BAMF_DESKTOP_FILE.
  * BamfLegacyScreen: Do not show the actions menu for desktop
    type window.
  * Fix return value of try_create_local_desktop_data.
  * Remove old webapp related code since now we do not use browser
    tab matching anymore.
  * Install typelib files into MA libdir.
  * BamfMatcher: honour the _GTK_APPLICATION_ID xprop.
  * Replace gtk_icon_theme_has_icon with gtk_icon_theme_lookup_icon.
- Remove bamf-voidreturn.diff.
- Spec cleanup.
* Wed May  7 2014 jengelh@inai.de
- Add bamf-voidreturn.diff to resolve a compile abort due to
  nonsensical syntax.
* Fri May  2 2014 jengelh@inai.de
- Initial package (version 0.5.0) for openSUSE
